@@ -1,7 +1,7 @@
-/*-----------------------------------------------------------------
+/* -----------------------------------------------------------------
  * Programmer(s): Daniel R. Reynolds @ SMU
  *                Radu Serban @ LLNL
- *-----------------------------------------------------------------
+ * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
  * Copyright (c) 2002-2019, Lawrence Livermore National Security
  * and Southern Methodist University.
@@ -11,11 +11,11 @@
  *
  * SPDX-License-Identifier: BSD-3-Clause
  * SUNDIALS Copyright End
- *-----------------------------------------------------------------
- * Header file for the deprecated direct linear solver interface in 
+ * -----------------------------------------------------------------
+ * Header file for the deprecated direct linear solver interface in
  * IDA; these routines now just wrap the updated IDA generic
  * linear solver interface in ida_ls.h.
- *-----------------------------------------------------------------*/
+ * -----------------------------------------------------------------*/
 
 #ifndef _IDADLS_H
 #define _IDADLS_H
@@ -26,26 +26,29 @@
 extern "C" {
 #endif
 
+
 /*=================================================================
   Function Types (typedefs for equivalent types in ida_ls.h)
   =================================================================*/
 
 typedef IDALsJacFn IDADlsJacFn;
 
-/*=================================================================
+/*===================================================================
   Exported Functions (wrappers for equivalent routines in ida_ls.h)
-  =================================================================*/
+  ===================================================================*/
 
-int IDADlsSetLinearSolver(void *ida_mem, SUNLinearSolver LS, SUNMatrix A);
+int IDADlsSetLinearSolver(void *ida_mem, SUNLinearSolver LS,
+                          SUNMatrix A);
 
 int IDADlsSetJacFn(void *ida_mem, IDADlsJacFn jac);
 
-int IDADlsGetWorkSpace(void *ida_mem, long int *lenrwLS, long int *leniwLS);
-  
+int IDADlsGetWorkSpace(void *ida_mem, long int *lenrwLS,
+                       long int *leniwLS);
+
 int IDADlsGetNumJacEvals(void *ida_mem, long int *njevals);
-  
-int IDADlsGetNumResEvals(void *ida_mem, long int *nfevalsLS);
-  
+
+int IDADlsGetNumResEvals(void *ida_mem, long int *nrevalsLS);
+
 int IDADlsGetLastFlag(void *ida_mem, long int *flag);
 
 char *IDADlsGetReturnFlagName(long int flag);
