@@ -19,10 +19,10 @@
  * -----------------------------------------------------------------*/
 
 /* Define SUNDIALS version numbers */
-#define SUNDIALS_VERSION "4.0.2"
+#define SUNDIALS_VERSION "4.1.0"
 #define SUNDIALS_VERSION_MAJOR 4
-#define SUNDIALS_VERSION_MINOR 0
-#define SUNDIALS_VERSION_PATCH 2
+#define SUNDIALS_VERSION_MINOR 1
+#define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
 
 /* FCMIX: Define Fortran name-mangling macro for C identifiers.
@@ -92,7 +92,7 @@
  * If working libraries for KLU support were found, then
  *     #define SUNDIALS_KLU 
  */
-/* #undef SUNDIALS_KLU */
+#define SUNDIALS_KLU
 
 /* Set if SUNDIALS is built with MPI support.
  * 
